!                                                                       
! $Id: iniphysiq.F 1403 2010-07-01 09:02:53Z fairhead $                 
!                                                                       
!                                                                       
!                                                                       
      SUBROUTINE iniphysiq_param(ngrid,nlayer,                          &
     &           punjours,                                              &
     &           pdayref,ptimestep,                                     &
     &           plat,plon,parea,pcu,pcv,                               &
     &           prad,pg,pr,pcpp,iflag_phys)                            
      USE dimphy 
      USE mod_grid_phy_lmdz 
      USE mod_phys_lmdz_para 
      USE geometry_mod, ONLY: cell_area, latitude_deg, longitude_deg 
!      USE inigeomphy_mod, ONLY : lonfi,latfi                           
                                                                        
                                                                        
      IMPLICIT NONE 
!                                                                       
!=======================================================================
!                                                                       
!   subject:                                                            
!   --------                                                            
!                                                                       
!   Initialisation for the physical parametrisations of the LMD         
!   martian atmospheric general circulation modele.                     
!                                                                       
!   author: Frederic Hourdin 15 / 10 /93                                
!   -------                                                             
!                                                                       
!   arguments:                                                          
!   ----------                                                          
!                                                                       
!   input:                                                              
!   ------                                                              
!                                                                       
!    ngrid                 Size of the horizontal grid.                 
!                          All internal loops are performed on that grid
!    nlayer                Number of vertical layers.                   
!    pdayref               Day of reference for the simulation          
!    firstcall             True at the first call                       
!    lastcall              True at the last call                        
!    pday                  Number of days counted from the North. Spring
!                          equinoxe.                                    
!                                                                       
!=======================================================================
!                                                                       
!-----------------------------------------------------------------------
!   declarations:                                                       
!   -------------                                                       
                                                                        
      REAL prad,pg,pr,pcpp,punjours 
                                                                        
      INTEGER ngrid,nlayer,iflag_phys 
      REAL plat(ngrid),plon(ngrid),parea(klon_glo) 
      REAL pcu(klon_glo),pcv(klon_glo) 
      INTEGER pdayref 
      INTEGER :: ibegin,iend,offset,indmin,indmax 
      REAL pi 
                                                                        
      REAL ptimestep 
      CHARACTER (LEN=20) :: modname='iniphysiq' 
      CHARACTER (LEN=80) :: abort_message 
                                                                        
      pi=2.*asin(1.) 
      print*,'INInnn ENTREE DANS INIPHYSIQ' 
      IF (nlayer.NE.klev) THEN 
         PRINT*,'STOP in inifis' 
         PRINT*,'Probleme de dimensions :' 
         PRINT*,'nlayer     = ',nlayer 
         PRINT*,'klev   = ',klev 
         abort_message = '' 
         CALL abort_gcm (modname,abort_message,1) 
      ENDIF 
                                                                        
      IF (ngrid.NE.klon_omp) THEN 
         PRINT*,'STOP in inifis' 
         PRINT*,'Probleme de dimensions :' 
         PRINT*,'ngrid     = ',ngrid 
         PRINT*,'klon   = ',klon_omp 
         abort_message = '' 
         CALL abort_gcm (modname,abort_message,1) 
      ENDIF 
!$OMP PARALLEL PRIVATE(ibegin,iend)                                     
!$OMP+         SHARED(parea,pcu,pcv,plon,plat)                          
                                                                        
      print*,'Dans iniphysiq ' 
      offset=klon_mpi_begin-1 
      indmin=offset+klon_omp_begin 
      indmax=offset+klon_omp_end 
       print*,'latitude0 deg ',latitude_deg(1),latitude_deg(klon_omp) 
                                                                        
      CALL iniphyparam(ngrid,nlayer,                                    &
     &           punjours,                                              &
     &           pdayref,ptimestep,                                     &
     &           prad,pg,pr,pcpp)                                       
                                                                        
                                                                        
      print*,'OK iniphyparam ',size(plat) 
                                                                        
!$OMP END PARALLEL                                                      
                                                                        
      print*,'ATTENTION !!! TRAVAILLER SUR INIPHYSIQ' 
      print*,'CONTROLE DES LATITUDES, LONGITUDES, PARAMETRES ...' 
                                                                        
      RETURN 
 9999 CONTINUE 
      abort_message ='Cette version demande les fichier rnatur.dat      &
     & et surf.def'                                                     
      CALL abort_gcm (modname,abort_message,1) 
                                                                        
                                                                        
      END                                           
